==> egroupware_1.0.0.007-2.dfsg.orig.tar.gz: egroupware-1.0.0.007-2.dfsg/phpsysinfo/includes/lang/sv.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sv.php,v 1.1 2004/01/20 20:59:41 reinerj Exp $
//
// translation by shockzor

$text['title']          = 'Systeminformation';

$text['vitals']         = 'Elementa';
$text['hostname']       = 'Vrdnamn';
$text['ip']             = 'IPaddress';
$text['kversion']       = 'Kernelversion';
$text['uptime']         = 'Drifttid';
$text['users']          = 'Antal anvndare';
$text['loadavg']        = 'Snittbelastning';

$text['hardware']       = 'Hrdvaruinformation';
$text['numcpu']         = 'Processorer';
$text['cpumodel']       = 'Modell';
$text['mhz']            = 'Klockfrekvens';
$text['cache']          = 'Cachestorlek';
$text['bogomips']       = 'Bogomips';
$text['pci']            = 'PCI-enheter';
$text['ide']            = 'IDE-enheter';
$text['scsi']           = 'SCSI-enheter';

$text['netusage']       = 'Ntverksanvndning';
$text['device']         = 'Enheter';
$text['received']       = 'Mottaget';
$text['sent']           = 'Skickat';
$text['errors']         = 'Fel/Frlorat';

$text['memusage']       = 'Minnesanvndning';
$text['phymem']         = 'Fysiskt minne';
$text['swap']           = 'Vxlingsminne';

$text['fs']             = 'Monterade filsystem';
$text['mount']          = 'Montera';
$text['partition']      = 'Partition';

$text['percent']        = 'Kapacitetsutnyttjande';
$text['type']           = 'Typ';
$text['free']           = 'Fritt';
$text['used']           = 'Anvnt';
$text['size']           = 'Storlek';
$text['totals']         = 'Totalt';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'inget';

$text['capacity']       = 'Kapacitet';
  
$text['template']       = 'Frlaga';
$text['language']       = 'Sprk';
$text['submit']         = 'Skicka';

$text['days']           = 'dagar';
$text['hours']          = 'timmar';
$text['minutes']        = 'minuter';
$text['created']        = 'Frn';
?>

==> egroupware_1.2.107-2.dfsg.orig.tar.gz: egroupware-1.2.107-2.dfsg/phpsysinfo/includes/lang/sv.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sv.php 21228 2006-04-06 13:52:08Z ralfbecker $
//
// translation by shockzor
// updated/edited by jetthe

$text['title']          = 'Systeminformation';

$text['vitals']         = 'Allmn information';
$text['hostname']       = 'Vrdnamn';
$text['ip']             = 'IP-adress';
$text['kversion']       = 'Kernel-version';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Drifttid';
$text['users']          = 'Aktuella anvndare';
$text['loadavg']        = 'Medelbelastning';

$text['hardware']       = 'Hrdvaruinformation';
$text['numcpu']         = 'Processorer';
$text['cpumodel']       = 'Modell';
$text['cpuspeed']       = 'Klockfrekvens';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cachestorlek';
$text['bogomips']       = 'Bogomips';

$text['pci']            = 'PCI-enheter';
$text['ide']            = 'IDE-enheter';
$text['scsi']           = 'SCSI-enheter';
$text['usb']            = 'USB-enheter';

$text['netusage']       = 'Ntverksanvndning';
$text['device']         = 'Enheter';
$text['received']       = 'Mottaget';
$text['sent']           = 'Skickat';
$text['errors']         = 'Fel/Frlorat';

$text['memusage']       = 'Minnesanvndning';
$text['phymem']         = 'Fysiskt minne';
$text['swap']           = 'Vxlingsminne';

$text['fs']             = 'Monterade filsystem';
$text['mount']          = 'Monteringspunkt';
$text['partition']      = 'Partition';

$text['percent']        = 'Kapacitetsutnyttjande';
$text['type']           = 'Typ';
$text['free']           = 'Ledigt';
$text['used']           = 'Anvnt';
$text['size']           = 'Storlek';
$text['totals']         = 'Totalt';

$text['kb']             = 'kB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'inga';

$text['capacity']       = 'Kapacitet';
  
$text['template']       = 'Mall';
$text['language']       = 'Sprk';
$text['submit']         = 'Skicka';

$text['days']           = 'dagar';
$text['hours']          = 'timmar';
$text['minutes']        = 'minuter';
$text['created']        = 'Skapat av';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
